<?php

declare(strict_types=1);

namespace Drupal\entity_crud_alter_status_message;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of entity crud alter status messages.
 */
final class EntityCrudAlterStatusMessageListBuilder extends ConfigEntityListBuilder {

  /**
   * Add EntityCrudAlterStatusMessageManager service.
   */
  private EntityCrudAlterStatusMessageManagerInterface $entityCrudAlterStatusMessageManager;

  /**
   * Constructs a new EntityCrudAlterStatusMessageListBuilder.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   * @param \Drupal\Core\Entity\EntityStorageInterface $storage
   *   The entity storage.
   * @param \Drupal\entity_crud_alter_status_message\EntityCrudAlterStatusMessageManagerInterface $entityCrudAlterStatusMessageManager
   *   The entity crud alter status message manager.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, EntityCrudAlterStatusMessageManagerInterface $entityCrudAlterStatusMessageManager,) {
    parent::__construct($entity_type, $storage);
    $this->entityCrudAlterStatusMessageManager = $entityCrudAlterStatusMessageManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity_type.manager')->getStorage($entity_type->id()),
      $container->get('entity_crud_alter_status_message.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['id'] = $this->t('ID');
    $header['entity_type'] = $this->t('Entity type');
    $header['entity_bundle'] = $this->t('Entity bundle');
    $header['crud_action'] = $this->t('Entity action');
    $header['message'] = $this->t('Message');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $entity_type = $entity->get('entity_type');
    $crud_mapping = $this->entityCrudAlterStatusMessageManager->getCrudMapping($entity_type);
    $action = $crud_mapping[$entity->get('crud_action')];
    $row['id'] = $entity->id();
    $row['entity_type'] = $entity->get('entity_type');
    $row['entity_bundle'] = $entity->get('entity_bundle');
    $row['crud_action'] = $action;
    $row['message'] = $entity->getMessage();
    return $row + parent::buildRow($entity);
  }

}
