<?php

namespace Drupal\Tests\entity_crud_alter_status_message\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests access for non-admin users.
 *
 * @group entity_crud_alter_status_message
 */
class EntityCrudAlterStatusMessageNonAdminAccessTest extends BrowserTestBase {

  use EntityCrudAlterStatusMessageTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_crud_alter_status_message',
    'node',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The admin user to use during the test.
   *
   * @var \Drupal\user\UserInterface
   */
  private $authenticatedUser;

  /**
   * Perform initial setup tasks that run before every test method.
   */
  public function setUp(): void {
    parent::setUp();
    $this->authenticatedUser = $this->DrupalCreateUser();
    $this->drupalCreateContentType([
      'type' => 'article',
      'name' => 'Article',
    ]);
    $this->createTestEntityCrudAlterStatusMessage('node', 'article', 'default', 'Article node created - test message');
  }

  /**
   * Tests routes for an authorized user.
   */
  public function testNonAdminUserAccess() {

    // Define the routes to test.
    $basicRoutes = [
      'entity.entity_crud_alter_status_message.collection' => [],
      'entity.entity_crud_alter_status_message.add_form' => [],
      'entity.entity_crud_alter_status_message.edit_form' => ['entity_crud_alter_status_message' => 'node.article.default'],
      'entity.entity_crud_alter_status_message.delete_form' => ['entity_crud_alter_status_message' => 'node.article.default'],
    ];

    // Test the routes.
    $this->routeAccessTest($basicRoutes, 403);
    $this->drupalLogin($this->authenticatedUser);
    $this->routeAccessTest($basicRoutes, 403);

  }

}
